@@ -1,6 +1,6 @@
 package MongoDBx::Class::Database;
 BEGIN {
-  $MongoDBx::Class::Database::VERSION = '0.6';
+  $MongoDBx::Class::Database::VERSION = '0.7';
 }
 
 # ABSTRACT: A MongoDBx::Class database object
@@ -16,7 +16,7 @@ MongoDBx::Class::Database - A MongoDBx::Class database object
 
 =head1 VERSION
 
-version 0.6
+version 0.7
 
 =head1 EXTENDS
 
@@ -25,7 +25,7 @@ L<MongoDB::Database>
 =head1 SYNOPSIS
 
 	# get a database object from your connection object
-	my $db = $dbx->conn->get_database($db_name); # or simply $dbx->conn->$db_name
+	my $db = $conn->get_database($db_name); # or simply $conn->$db_name
 
 =head1 DESCRIPTION
 
@@ -92,7 +92,7 @@ L<MongoDBx::Class::Connection>, L<MongoDB::Database>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Ido Perlmuter.
+Copyright 2010-2011 Ido Perlmuter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
